==> qtjambi-remoteobjects-6.2.9-sources.jar: io/qt/remoteobjects/QtROIoDeviceBase.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QtROIoDeviceBase</p>
 */
public abstract class QtROIoDeviceBase extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROIoDeviceBase.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QtROIoDeviceBase {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        protected java.lang.String deviceType(){
            return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native java.lang.String deviceType_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    

    public final Signal0 disconnected = new Signal0();

    public final Signal0 readyRead = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QtROIoDeviceBase(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROIoDeviceBase() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROIoDeviceBase(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROIoDeviceBase instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public final void addSource(java.lang.String arg__1){
        addSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void addSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public final void initializeDataStream(){
        initializeDataStream_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void initializeDataStream_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean isClosing(){
        return isClosing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isClosing_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.remoteobjects.QtROIoDeviceBase.ReadResult read(){
        return read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.remoteobjects.QtROIoDeviceBase.ReadResult read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QSet<java.lang.String> remoteObjects(){
        return remoteObjects_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QSet<java.lang.String> remoteObjects_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void removeSource(java.lang.String arg__1){
        removeSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void removeSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @io.qt.QtUninvokable
    public long bytesAvailable(){
        return bytesAvailable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long bytesAvailable_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void close_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract io.qt.core.QIODevice connection();
    
    @io.qt.QtUninvokable
    private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected abstract java.lang.String deviceType();
    
    @io.qt.QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected abstract void doClose();
    
    @io.qt.QtUninvokable
    private native void doClose_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public boolean isOpen(){
        return isOpen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isOpen_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public void write(io.qt.core.QByteArray data){
        write_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @io.qt.QtUninvokable
    private native void write_native_cref_QByteArray(long __this__nativeId, long data);
    
    @io.qt.QtUninvokable
    public void write(io.qt.core.QByteArray data, long arg__2){
        write_native_cref_QByteArray_long_long(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), arg__2);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_cref_QByteArray_long_long(long __this__nativeId, long data, long arg__2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QtROIoDeviceBase(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QtROIoDeviceBase(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QtROIoDeviceBase instance, QDeclarativeConstructor constructor);
    
    public class ReadResult{
        public final QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType;
        public final String result;
        
        private ReadResult(QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType, String result) {
            super();
            this.packetType = packetType;
            this.result = result;
        }
    }
}

==> qtjambi-remoteobjects-6.2.12-sources.jar: io/qt/remoteobjects/QtROIoDeviceBase.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QtROIoDeviceBase</p>
 */
public abstract class QtROIoDeviceBase extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROIoDeviceBase.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROIoDeviceBase {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected java.lang.@NonNull String deviceType(){
            return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String deviceType_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    

    public final @NonNull Signal0 disconnected = new Signal0();

    public final @NonNull Signal0 readyRead = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROIoDeviceBase() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROIoDeviceBase(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROIoDeviceBase instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public final void addSource(java.lang.@NonNull String arg__1){
        addSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void addSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @QtUninvokable
    public final void initializeDataStream(){
        initializeDataStream_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void initializeDataStream_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean isClosing(){
        return isClosing_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isClosing_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read(){
        return read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.remoteobjects.QtROIoDeviceBase.@Nullable ReadResult read_native_ref_QtRemoteObjects_QRemoteObjectPacketTypeEnum_ref_QString(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QSet<java.lang.@NonNull String> remoteObjects(){
        return remoteObjects_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QSet<java.lang.String> remoteObjects_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void removeSource(java.lang.@NonNull String arg__1){
        removeSource_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void removeSource_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    @QtUninvokable
    public long bytesAvailable(){
        return bytesAvailable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long bytesAvailable_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public void close(){
        close_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void close_native(long __this__nativeId);
    
    @QtUninvokable
    public abstract io.qt.core.@Nullable QIODevice connection();
    
    @QtUninvokable
    private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    protected abstract java.lang.@NonNull String deviceType();
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    protected abstract void doClose();
    
    @QtUninvokable
    private native void doClose_native(long __this__nativeId);
    
    @QtUninvokable
    public boolean isOpen(){
        return isOpen_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOpen_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data){
        write_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray(long __this__nativeId, long data);
    
    @QtUninvokable
    public void write(io.qt.core.@NonNull QByteArray data, long arg__2){
        write_native_cref_QByteArray_qint64(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), arg__2);
    }
    
    @QtUninvokable
    private native void write_native_cref_QByteArray_qint64(long __this__nativeId, long data, long arg__2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QtROIoDeviceBase(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROIoDeviceBase(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROIoDeviceBase instance, QDeclarativeConstructor constructor);
    
    public class ReadResult{
        public final QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType;
        public final String result;
        
        private ReadResult(QtRemoteObjects.QRemoteObjectPacketTypeEnum packetType, String result) {
            super();
            this.packetType = packetType;
            this.result = result;
        }
    }
}
